module.exports = {
    parser: 'vue-eslint-parser',
    parserOptions: {
        parser: '@typescript-eslint/parser',
        ecmaVersion: 2020,
        sourceType: 'module',
        ecmaFeatures: {
            jsx: true,
        },
    },

    extends: [
        'plugin:vue/vue3-recommended',
        'plugin:@typescript-eslint/recommended',
        'prettier/@typescript-eslint',
        'plugin:prettier/recommended',
        'eslint:recommended',
    ],
    rules: {
        // indent: ['error', 4, { SwitchCase: 1 }],
        'vue/script-indent': ['error', 4, { baseIndent: 1, switchCase: 1 }],
        'vue/html-indent': ['error', 4, { baseIndent: 1 }],
        //具体说明：https://www.npmjs.com/package/@typescript-eslint/eslint-plugin
        //函数需要详细的返回类型
        '@typescript-eslint/explicit-function-return-type': 'off',
        //禁止使用any类型
        '@typescript-eslint/no-explicit-any': 'off',
        //除了import语句外，禁止使用require语句
        '@typescript-eslint/no-var-requires': 'off',
        //禁止使用空函数
        '@typescript-eslint/no-empty-function': 'off',
        //强制为自定义事件名称指定大小写
        'vue/custom-event-name-casing': 'off',
        //定义前禁止使用
        'no-use-before-define': 'off',
        //定义前禁止使用
        '@typescript-eslint/no-use-before-define': 'off',
        //禁止ts注释
        '@typescript-eslint/ban-ts-comment': 'error',
        //禁止使用特定的类型，英文原文：Bans specific types from being used
        '@typescript-eslint/ban-types': 'off',
        //禁止使用！开头判断非空断言
        '@typescript-eslint/no-non-null-assertion': 'off',
        //在导出的函数或类的public方法中，需要指定返回类型和方法类型
        '@typescript-eslint/explicit-module-boundary-types': 'off',
        //禁止未使用的变量规则
        '@typescript-eslint/no-unused-vars': [
            'error',
            {
                argsIgnorePattern: '^h$',
                varsIgnorePattern: '^h$',
            },
        ],
        //禁止未使用的变量规则
        'no-unused-vars': 'off',
        //function参数的括号前需要有空格
        'space-before-function-paren': 'off',
        //vue prop要写默认值
        'vue/require-default-prop': 'off',
        'vue/require-prop-types': 'off',
        //不能写 v-bind 只能写:
        'vue/v-bind-style': 'off',
        //不能写 v-html
        'vue/no-v-html': 'off',
        //节点括号必须在一行
        'vue/html-closing-bracket-newline': 'off',
        'vue/attribute-hyphenation': 'off',
        'vue/max-attributes-per-line': 'off',
        'vue/attributes-order': 'off',
        'vue/html-self-closing': 'off',
        'vue/singleline-html-element-content-newline': 'off',
        'vue/multiline-html-element-content-newline': 'off',
        'prefer-const': 'off',
        //不允许prop在组件内更改
        'vue/no-mutating-props': 'off',
        'vue/require-explicit-emits': 'off',
        'vue/html-indent': 'off',
        '@typescript-eslint/no-unused-vars': 'off',
        'vue/component-definition-name-casing': 'off',
        'vue/html-self-closing': [
            'error',
            {
                html: {
                    void: 'always',
                    normal: 'never',
                    component: 'always',
                },
                svg: 'always',
                math: 'always',
            },
        ],
    },
}
