/*
ajax请求函数模块
返回值: promise对象(异步返回的数据是: response.data)
 */
import axios from 'axios'
import qs from 'qs'
import { tableSorter, store } from 'eyas-bashou-admin'

/*
 *基础ajax请求
 */
export function ajax(dataConfig) {
    return new Promise(function (resolve, reject) {
        const data = {
            method: dataConfig.method,
            url: dataConfig.url,
            ...dataConfig.config,
        }

        handleApi(data, dataConfig, resolve, reject)
    })
}

/*
 *传输的是from数据
 */
export function fromApi(dataConfig, columns) {
    return new Promise(function (resolve, reject) {
        const { order, orderRule } = tableSorter(columns)
        if (order) {
            dataConfig.config.data.order = order
        }
        if (orderRule) {
            dataConfig.config.data.orderRule = orderRule
        }

        const data = {
            method: dataConfig.method,
            url: dataConfig.url,
            headers: {
                'Content-Type': 'application/x-www-form-urlencoded',
            },
            data: qs.stringify(dataConfig.config.data),
        }

        handleApi(data, dataConfig, resolve, reject)
    })
}

/*
 *传输的是blob数据
 */
export function blobApi(dataConfig) {
    return new Promise(function (resolve, reject) {
        const data = {
            method: dataConfig.method,
            url: dataConfig.url,
            responseType: 'blob',
            data: dataConfig.config.data,
        }

        handleApi(data, dataConfig, resolve, reject)
    })
}

function handleApi(data, dataConfig, resolve, reject) {
    // 执行异步ajax请求
    if (!dataConfig.notLoading) {
        store.commit('loadingShowFun', 1)
    }
    const promise = axios(data)
    promise
        .then(function (response) {
            if (!dataConfig.notLoading) {
                store.commit('loadingShowFun', -1)
            }
            if (response.status === 200) {
                resolve(response)
            } else {
                reject(response)
            }
        })
        .catch(function (error) {
            if (!dataConfig.notLoading) {
                store.commit('loadingShowFun', -1)
            }
            //失败了调用reject()
            reject(error)
        })
}
