import { notification, message } from 'ant-design-vue'
import axios from 'axios'

export default function interceptor(app, router) {
    axios.defaults.headers.post['Content-Type'] = 'application/json'
    // 添加请求拦截器
    axios.interceptors.request.use(
        function (config) {
            config.headers['X-Requested-With'] = 'XMLHttpRequest'
            config.headers['Cache-Control'] = 'no-cache'
            config.headers['Pragma'] = 'no-cache'
            const res = localStorage.getItem('token')
            config.headers.common['Authentication'] =
                res !== undefined && res !== '' && res !== 'undefined' ? res : ''
            return config
        },
        function (error) {
            return Promise.reject(error)
        }
    )
    // 添加响应拦截器
    axios.interceptors.response.use(
        async function (response: any) {
            // 对响应数据做点什么
            if (response.headers.authentication) {
                localStorage.setItem('token', response.headers.authentication)
                localStorage.setItem('lastToken', response.headers.authentication)
            }
            return response
        },
        function (error) {
            localStorage.setItem('responseCode', error.response.data.returnCode)
            const { returnCode, returnInfo } = error.response.data
            const codeMap = {
                success: [400],
                fail: [500, 502],
                lose: [402, 403, 417, 427],
                ban: [401, 420, 430],
            }

            if (codeMap.success.includes(returnCode)) {
                message.error(error.response.data.data.message, 4)
            } else if (codeMap.lose.includes(returnCode)) {
                message.error(returnInfo, 4)
            } else if (codeMap.fail.includes(returnCode)) {
                notification['error']({ message: '服务器出错，请联系管理员' })
            } else if (codeMap.ban.includes(returnCode)) {
                message.error(returnInfo, 4)
                router.replace({ name: 'Login' })
            }

            return error.response
        }
    )
    app.config.globalProperties.$axios = axios
}
