import { reactive, createVNode } from 'vue'
import { ExclamationCircleOutlined } from '@ant-design/icons-vue'
import { Modal } from 'ant-design-vue'

const handleModel = (modalData = {}, resetFn = () => {}) => {
    const modalState = reactive({
        modalVisible: false, //弹窗开关
        modalPattern: '', //判断类型 add or edit
        title: '', //弹窗标题
    })

    //弹窗取消时
    const cancelModal = () => {
        modalState.modalVisible = false
        modalState.modalPattern = ''
        modalState.title = ''
        modalReset()
        resetFn()
    }

    //弹窗打开时
    const openModal = (key = 'add', title = '') => {
        modalState.modalVisible = true
        modalState.modalPattern = key
        modalState.title = title
    }

    //重置弹窗方法
    const modalReset = () => {
        for (const item in modalData) {
            modalData[item].info = null
            modalData[item].value = null
            modalData[item].id = null
        }
    }

    const creatModal = ({
        okText = '确定',
        cancelText = '取消',
        content = '',
        title = '',
        okFn = (okData) => {},
        okData = {},
        cancelFn = (cancelData) => {},
        cancelData = {},
    }) => {
        Modal.confirm({
            title,
            icon: createVNode(ExclamationCircleOutlined),
            okText,
            content,
            cancelText,
            onOk() {
                okFn(okData)
            },
            onCancel() {
                cancelFn(cancelData)
            },
            zIndex: 1000,
        })
    }

    return {
        creatModal,
        openModal,
        modalState,
        cancelModal, //取消弹窗时
    }
}

export { handleModel }
