import { apiList, Server, store } from 'eyas-bashou-admin'
import { message } from 'ant-design-vue'

interface arrTabRoute {
    key: String
    path: any
    name: String
    nameArr: any
}

//tab列表里规定的数据格式
interface tabtype {
    key: String
    title: String
    icon: String
    path?: Array<String>
    children?: Array<tabtype>
}

//扁平化处理
const integrationRouter = (tabList): Array<arrTabRoute> => {
    const routeArr: Array<arrTabRoute> = [
        {
            key: 'welcome',
            path: ['welcome'],
            nameArr: ['欢迎'],
            name: '欢迎',
        },
    ]

    const recursionRouter = (
        tab: Array<tabtype>,
        pathArr: Array<String> = [],
        nameArr: Array<String> = []
    ): void => {
        tab.forEach((item) => {
            if (item.children) {
                recursionRouter(item.children, [...pathArr, item.key], [...nameArr, item.title])
            } else {
                routeArr.push({
                    key: item.key,
                    path: [...pathArr, item.key],
                    nameArr: [...nameArr, item.title],
                    name: item.title,
                })
            }
        })
    }

    recursionRouter(tabList)

    return routeArr
}

//申请接口
const handleTabList = async () => {
    const data = {
        method: 'GET',
        url: apiList.sidebar,
    }
    return await Server.Axios(data)
}

//申请权限接口
const handleAuthority = async () => {
    const data = {
        method: 'GET',
        url: apiList.button,
    }
    return await Server.Axios(data)
}

//进入路由之前的钩子
async function routerBefore(router, to, detail) {
    if (to.name === 'Version') return

    if (store.state.tabList !== null && to.matched.length === 0) {
        router.replace({ name: 'notFound' })
        return
    }

    if (to.name === 'Login') {
        store.commit('tabList', null)
        store.commit('authority', {})
        localStorage.removeItem('token')
        return
    }

    if (localStorage.getItem('token')) {
        if (store.state.tabList === null && to.path.split('/')[1] === 'index') {
            const res: any = await handleTabList()
            store.commit('tabList', res.data.data.tabList)
            if (res.data.data.tabList.length === 0) {
                message.warning('该角色没有权限，请联系管理员')
            }
            const authority: any = await handleAuthority()
            store.commit('authority', authority.data.data.buttonMap)
            const routerArr = integrationRouter(res.data.data.tabList).map((item) => {
                return {
                    path: '/index/' + item.key,
                    name: item.key,
                    component: () => import(`../views/page/${item.key}/${item.key}.vue`),
                    meta: {
                        path: item.path.reverse(),
                        keepAlive: true,
                        name: item.name,
                        nameArr: item.nameArr,
                    },
                }
            })
            console.log(routerArr)

            //判断静态路由的权限
            routerArr.forEach((element) => {
                detail.forEach((el) => {
                    if (el.meta.father === element.name) {
                        routerArr.push(el)
                    }
                })
            })

            await router.addRoute({
                path: '/index',
                name: 'Index',
                redirect: '/index/welcome',
                component: () => import('../views/index.vue'),
                children: [...routerArr],
            })
            router.replace({ path: to.path, query: to.query })
        }
    } else if (to.name !== 'Login') {
        router.replace({ name: 'Login' })
    }
}

export { routerBefore }
