import { createRouter, createWebHashHistory, RouteRecordRaw } from 'vue-router'
import { routerBefore } from './hooks'
import { staticRoutes } from '@/router/static-routes'

const routes: Array<RouteRecordRaw> = [
    {
        path: '/',
        redirect: '/index',
    },
    {
        path: '/login',
        name: 'Login',
        component: () => import('../views/login/login.vue'),
    },
    {
        path: '/version',
        name: 'Version',
        component: () => import('../views/public/version.vue'),
    },
    {
        path: '/index',
        name: 'Index',
        redirect: '/index/welcome',
        component: () => import('../views/index.vue'),
        children: [
            {
                path: '/index/welcome',
                name: 'welcome',
                component: () => import('../views/page/welcome/welcome.vue'),
                meta: {
                    path: ['welcome'],
                    keepAlive: true,
                    name: '欢迎',
                    nameArr: ['welcome'],
                },
            },
        ],
    },
    {
        path: '/notFound',
        name: 'notFound',
        component: () => import('../views/page/notFound/notFound.vue'),
    },
]

const router = createRouter({
    history: createWebHashHistory(),
    routes,
})

router.beforeEach(async (to: any) => {
    await routerBefore(router, to, staticRoutes)
})

export default router
