import { createStore } from 'vuex'
import route from '../router'
import * as otherModuls from '@/store'

interface stateType {
    handleTab: Boolean
    tagData: Array<tagData>
    activeTag: String
    nowRoutePath: Array<String>
    spinning: number
    tabList: any
    authority: any
}

interface tagData {
    name: String
    path: Array<String>
    key: String
    query?: any
}

export default createStore({
    state: <stateType>{
        handleTab: false,
        activeTag: '',
        tagData: [],
        nowRoutePath: [],
        spinning: 0,
        tabList: null,
        authority: {},
    },
    mutations: {
        loadingShowFun(state, data) {
            state.spinning = state.spinning + data
        },

        tabList(state, data) {
            state.tabList = data
        },

        handleTab(state: stateType) {
            state.handleTab = !state.handleTab
        },
        /*
      点击右侧tag里的选项或者初始渲染时，进行tag数组的组装
    */
        clickTabItem(state: stateType, data: tagData) {
            let ifCopy: Boolean = false
            state.tagData.forEach((item) => {
                //判断当前点击的key在tag数组中是否存在 存在则把激活数组改为当前
                if (item.key === data.path[0]) {
                    ifCopy = true
                }
            })
            state.activeTag = data.path[0]
            if (ifCopy) {
                return
            }
            //不存在则把刚刚点击的key添加到tag数组中 并把激活key改为当前
            if (data.path[0] == 'welcome') {
                state.tagData.unshift({
                    name: data.name,
                    path: data.path,
                    key: data.path[0],
                })
            } else {
                state.tagData.push({
                    name: data.name,
                    path: data.path,
                    key: data.path[0],
                })
            }
        },
        saveQuery(state, { key, query }) {
            state.tagData.forEach((item) => {
                if (item.key == key) {
                    item.query = query
                }
            })
        },
        readThisQuery(state, data) {
            state.tagData.forEach((item) => {
                if (item.key == data) {
                    route.push({ query: item.query || {} })
                }
            })
        },

        //点击tag改变当前标签页
        changeTagRouter(state, data) {
            state.tagData.forEach((item) => {
                if (item.key === data) {
                    state.nowRoutePath = item.path
                }
            })
        },

        //关闭其他标签页
        closeOtherTag(state, data) {
            state.tagData.splice(0, state.tagData.length, {
                name: data.name,
                path: data.path,
                key: data.path[0],
            })
        },
        //关闭其他标签页
        authority(state, data) {
            state.authority = data
        },

        closeAllTag(state) {
            state.tagData = []
        },

        //删除当前标签页
        editTagRouter(state, data): void {
            state.tagData.forEach((item, index) => {
                if (item.key === data) {
                    if (state.activeTag == data) {
                        let name: any = ''
                        let path: Array<String> = []
                        if (state.tagData.length === 1) {
                            name = 'index'
                            path = []
                        } else {
                            name =
                                index === 0
                                    ? state.tagData[index + 1].key
                                    : state.tagData[index - 1].key
                            path =
                                index === 0
                                    ? state.tagData[index + 1].path
                                    : state.tagData[index - 1].path
                        }
                        state.nowRoutePath = path
                        route.replace({ name })
                    }
                    state.tagData.splice(index, 1)
                }
            })
        },
    },
    actions: {
        hiddenTab({ commit }) {
            commit('handleTab')
        },
    },
    modules: otherModuls,
})
