import { apiList, Server, router, store } from 'eyas-bashou-admin'
import md5 from 'js-md5'
import { message } from 'ant-design-vue'
import { initDataFn } from './initData'

const { codeImage, formRules } = initDataFn()

//验证码的key
let verificationCode = null

//是否需要验证码接口
const isEnabledVerificationCode = async () => {
    const data = {
        method: 'GET',
        url: apiList.isEnabledVerificationCode,
    }
    const result: any = await Server.Axios(data)
    if (result.data.data) {
        await refreshCode()
        formRules.code = [
            { required: true, message: '请输入验证码', trigger: 'blur' },
            {
                len: 4,
                message: '请输入4位验证码',
                trigger: 'blur',
            },
        ]
    }
}

//验证码图片申请
const refreshCode = async () => {
    const data = {
        config: { responseType: 'arraybuffer' },
        method: 'GET',
        url: apiList.refreshCode,
    }

    const result: any = await Server.Axios(data)
    verificationCode = result.headers['verification-code']
    codeImage.value =
        'data:image/png;base64,' +
        btoa(
            new Uint8Array(result.data).reduce((data, byte) => data + String.fromCharCode(byte), '')
        )
}

//点击验证码图片
const clickCode = async () => {
    await refreshCode()
}

//登录密码是否正确
const login = async (formData) => {
    const data = {
        method: 'POST',
        url: apiList.account,
        config: {
            data: {
                account: formData.account,
                password: md5(formData.password),
                noLogin30: formData.autoLogin ? 1 : 0,
                code: verificationCode ? formData.code : null,
                validCertificate: verificationCode || null,
            },
        },
    }
    Server.Axios(data).then((res: any) => {
        store.commit('closeAllTag')
        if (res.data.returnCode === 417) {
            if (codeImage.value) {
                refreshCode()
            }
        } else if (res.data.returnCode === 200) {
            localStorage.setItem('token', res.data.data)
            message.success('   欢迎回来   ', 3)
            router.replace({ name: 'Index' })
        }
    })
}

export {
    formRules,
    codeImage, //是否需要验证码
    isEnabledVerificationCode, //是否需要验证码接口
    clickCode, //点击验证码图片
    login, //登录密码是否正确
}
