import { apiList, Server, handleModel, paginationFn } from 'eyas-bashou-admin'

import { message } from 'ant-design-vue'

function hooks(initData) {
    const {
        loading,
        columns, //列表数据
        modalData, //列表数据
        tableData, //列表搜索条件
        userPageData, //弹窗数据
        screenData, //筛选模糊查询数据
    } = initData
    const {
        modalState,
        cancelModal, //取消弹窗时
        openModal,
    } = handleModel(modalData)

    let thisQuery = {
        dictName: '',
    }
    function getQuery(query) {
        if (query == {}) {
            return
        }
        thisQuery = query
        getList()
    }

    function getList() {
        loading.value = true
        Server.Axios({
            method: 'GET',
            url: apiList.dictValueList,
            config: {
                params: {
                    dictName: thisQuery.dictName,
                    dictValue: userPageData.dictValue || null,
                    dictCode: userPageData.dictCode || null,
                },
            },
        }).then((res: any) => {
            tableData.value = res.data.data
            loading.value = false
        })
    }

    const addDicFn = (() => {
        const modalAddOpen = () => {
            openModal('add', '新增字典详情')
        }
        function modalAddClickOk() {
            Server.Axios({
                method: 'POST',
                url: apiList.addValue,
                config: {
                    data: {
                        dictName: thisQuery.dictName,
                        dictCode: modalData.dictCode.value,
                        dictValue: modalData.dictVal.value,
                        sortId: modalData.sortId.value,
                    },
                },
            }).then((res: any) => {
                message.success(res.data.returnInfo)
                getList()
                cancelModal()
            })
        }
        return { modalAddClickOk, modalAddOpen }
    })()

    const editDicFn = (() => {
        const modalEditOpen = (record) => {
            modalData.dictCode.value = record.dictCode
            modalData.dictCode.dictId = record.dictId
            modalData.dictVal.value = record.dictValue
            modalData.sortId.value = record.sortId
            openModal('update', '编辑字典详情')
        }
        function modalEditClickOk() {
            Server.Axios({
                method: 'PUT',
                url: apiList.updateValue,
                config: {
                    data: {
                        dictId: modalData.dictCode.dictId,
                        dictName: thisQuery.dictName,
                        dictCode: modalData.dictCode.value,
                        dictValue: modalData.dictVal.value,
                        sortId: modalData.sortId.value,
                    },
                },
            }).then((res: any) => {
                tableData.value = res.data.data
                message.success(res.data.returnInfo)
                getList()
                cancelModal()
            })
        }

        return { modalEditOpen, modalEditClickOk }
    })()

    function onDelete(key) {
        Server.Axios({
            method: 'DELETE',
            url: apiList.deleteValue + `/${key.dictId}`,
        }).then((res: any) => {
            message.success(res.data.returnInfo)
            getList()
        })
    }

    //分页操作
    const { paginationData, pageChange, onShowSizeChange, updateTotal } = paginationFn(getList)

    return {
        paginationData,
        pageChange,
        onShowSizeChange,
        updateTotal,
        loading,
        columns, //列表数据
        modalData, //列表数据
        tableData, //列表搜索条件
        userPageData, //弹窗数据
        screenData, //筛选模糊查询数据
        addDicFn,
        modalState,
        cancelModal, //取消弹窗时
        openModal,
        editDicFn,
        getList,
        onDelete,
        getQuery,
    }
}

export { hooks }
