import { apiList, Server, handleModel, paginationFn } from 'eyas-bashou-admin'

import { message } from 'ant-design-vue'

function hooks(initData) {
    const {
        loading,
        columns, //列表数据
        modalData, //列表数据
        tableData, //列表搜索条件
        screenData, //筛选模糊查询数据
        paginationData, //分页数据
    } = initData

    const {
        modalState, //弹窗数据
        cancelModal, //取消弹窗时
        openModal, //打开弹窗
    } = handleModel(modalData)
    const { pageChange, onShowSizeChange, updateTotal } = paginationFn(getList, paginationData)

    function getList() {
        Server.Axios({
            method: 'GET',
            url: apiList.dictDefineListPage,
            config: {
                params: {
                    pageNo: paginationData.pageNo,
                    pageSize: paginationData.pageSize,
                    dictName: screenData.dictName.value,
                    description: screenData.description.value,
                },
            },
        }).then((res: any) => {
            tableData.value = res.data.data.list.map((item, index) => {
                item.index = (paginationData.pageNo - 1) * paginationData.pageSize + index + 1
                item.oriDictName = item.dictName
                return item
            })
            updateTotal(res.data.data.total)
        })
    }

    //查询字典
    function handleSearch(e) {
        paginationData.pageNo = 1
        getList()
    }

    //添加
    const addDicFn = (() => {
        const modalAddOpen = (modalState) => {
            openModal('add', '新增')
        }
        function modalAddClickOk() {
            Server.Axios({
                method: 'POST',
                url: apiList.addDictDefine,
                config: {
                    data: {
                        dictName: modalData.dictName.value,
                        description: modalData.describe.value,
                    },
                },
            }).then((res: any) => {
                message.success(res.data.returnInfo)
                cancelModal()
                getList()
            })
        }
        return { modalAddClickOk, modalAddOpen }
    })()

    const editDicFn = (() => {
        const modalEditOpen = (record) => {
            modalData.dictName.value = record.dictName
            modalData.describe.value = record.description
            modalData.dictName.oriDictName = record.oriDictName
            openModal('update', '编辑数据字典')
        }
        function modalEditClickOk() {
            Server.Axios({
                method: 'PUT',
                url: apiList.updateDictDefine,
                config: {
                    data: {
                        dictName: modalData.dictName.value,
                        description: modalData.describe.value,
                        oriDictName: modalData.dictName.oriDictName,
                    },
                },
            }).then((res: any) => {
                message.success(res.data.returnInfo)
                cancelModal()
                getList()
            })
        }

        return { modalEditOpen, modalEditClickOk }
    })()

    return {
        loading,
        columns, //列表数据
        modalData, //列表数据
        tableData, //列表搜索条件
        screenData, //筛选模糊查询数据
        paginationData,
        modalState,
        cancelModal, //取消弹窗时
        addDicFn,
        editDicFn,
        updateTotal,
        handleSearch,
        openModal,
        getList,
        pageChange,
        onShowSizeChange,
    }
}
export { hooks }
