import { apiList, Server, handleModel, paginationFn } from 'eyas-bashou-admin'
import { message } from 'ant-design-vue'

function hooks(initData) {
    const {
        columns, //列表数据
        screenData, //筛选模糊查询数据
        tableData,
        modalData,
        paginationData,
    } = initData

    //获取当前条件下的列表数据
    const getGlobalList = () => {
        const data: any = {
            method: 'GET',
            url: apiList.globalParamListPage,
            config: {
                params: {
                    pageSize: paginationData.pageSize,
                    paramName: screenData.paramName.value || '',
                    paramValue: screenData.paramValue.value || '',
                    paramDescription: screenData.paramDescription.value || '',
                    pageNo: paginationData.pageNo || 1,
                },
            },
        }

        Server.Axios(data).then((res: any) => {
            //填充列表数据和总条数
            res.data.data.list.forEach((element, index) => {
                element.index = (paginationData.pageNo - 1) * 10 + index + 1
            })
            tableData.value = res.data.data.list
            updateTotal(res.data.data.total)
        })
    }

    //弹窗的操作
    const { modalState, cancelModal, openModal } = handleModel(modalData)

    //分页操作
    const { pageChange, onShowSizeChange, updateTotal } = paginationFn(
        getGlobalList,
        paginationData
    )

    //添加全局变量
    const addFn = (() => {
        //增加弹窗前触发的钩子
        const modalAddOpenBefore = (modalState) => {
            openModal(modalState.key, modalState.title)
        }
        //添加全局变量
        const addGlobal = () => {
            Server.Axios({
                method: 'POST',
                url: apiList.addGlobalParam,
                config: {
                    data: {
                        paramName: modalData.name.value,
                        paramValue: modalData.value.value,
                        paramDescription: modalData.info.value,
                    },
                },
            }).then((res: any) => {
                message.success('添加全局变量成功', 4)
                getGlobalList()
                cancelModal()
            })
        }

        return {
            addGlobal,
            modalAddOpenBefore,
        }
    })()

    //删除全局变量
    const deleteGlobalFn = (e) => {
        Server.Axios({
            method: 'DELETE',
            url: apiList.deleteGlobalParam,
            config: {
                params: {
                    id: e.globalParamId,
                },
            },
        }).then((res: any) => {
            message.success('删除成功', 4)
            getGlobalList()
        })
    }

    //添加修改变量
    const editFn = (() => {
        //修改弹窗前触发的钩子
        const beforeEditTable = (mData) => {
            modalData.name.value = mData.paramName
            modalData.value.value = mData.paramValue
            modalData.info.value = mData.paramDescription
            openModal('update', '编辑全局变量')
        }

        //编辑全局变量
        const editGlobal = () => {
            Server.Axios({
                method: 'PUT',
                url: apiList.updateGlobalParam,
                config: {
                    data: {
                        paramName: modalData.name.value,
                        paramValue: modalData.value.value,
                        paramDescription: modalData.info.value,
                    },
                },
            }).then((res: any) => {
                message.success('修改全局变量成功', 4)
                getGlobalList()
                cancelModal()
            })
        }

        return {
            beforeEditTable,
            editGlobal,
        }
    })()

    //查询用户
    const clickSearch = (data) => {
        paginationData.pageNo = 1
        getGlobalList()
    }

    return {
        columns, //列表数据
        screenData, //筛选模糊查询数据
        tableData, //列表数据
        getGlobalList, //获取当前条件下的列表数据
        paginationData, //页码数据
        pageChange, //点击页码时
        onShowSizeChange, //修改每页几条
        modalData, //弹窗数据
        modalState, //弹窗数据
        addFn, //添加全局变量
        editFn, //修改全局变量
        deleteGlobalFn, //删除当事人
        clickSearch, //查询当事人
        cancelModal,
    }
}
export { hooks }
