import {
    apiList,
    Server,
    handleModel,
    ifOpen,
    assignmentOpen,
    findParentData,
} from 'eyas-bashou-admin'

import { message } from 'ant-design-vue'

function hooks(initData) {
    const {
        modalData, //列表数据
        // treeData, //列表搜索条件
        userPageData, //弹窗数据
        columns, //列表数据
        screenData, //筛选模糊查询数据
        personColumns,
        paginationData,
        whoOpen,
        treeData,
    } = initData
    const { modalState, cancelModal, openModal } = handleModel(modalData)

    const editOrgFn = (() => {
        function modalEditOpen(mData) {
            Server.Axios({
                method: 'GET',
                url: apiList.details + `/${mData.organizationId}`,
            }).then((res: any) => {
                const { data } = res.data
                modalData.organizationName.value = data.organizationName
                modalData.organizationName.organizationId = data.organizationId
                modalData.admin.value = data.userId ? data.userId : null
                modalData.user.value = data.orgUserIds
                modalData.organizationBelong.value = data.parentId == '0' ? '' : data.parentId
                openModal('update', '编辑部门')
            })
        }

        function modalEditClickOk() {
            Server.Axios({
                method: 'PUT',
                url: apiList.organization,
                config: {
                    data: {
                        organizationName: modalData.organizationName.value,
                        organizationId: modalData.organizationName.organizationId,
                        userId: modalData.admin.value,
                        parentId: modalData.organizationBelong.value || '0',
                        orgUserIds: modalData.user.value,
                    },
                },
            }).then((res: any) => {
                message.success(res.data.returnInfo)
                cancelModal()
                getDepartList()
            })
        }
        return { modalEditClickOk, modalEditOpen }
    })()

    const deleteOrgFn = (() => {
        // 删除部门
        function deleteDepart(item) {
            Server.Axios({
                method: 'DELETE',
                url: apiList.organization + `?organizationId=${item.organizationId}`,
                config: {
                    data: {
                        organizationId: item.organizationId,
                        parentId: item.parentId,
                    },
                },
            }).then((res: any) => {
                getDepartList()
                message.success(res.data.returnInfo)
            })
        }
        return { deleteDepart }
    })()

    const personDetail = (() => {
        function handleLink(item) {
            //获取当前部门人员列表信息
            Server.Axios({
                method: 'GET',
                url: apiList.orgNameAndUserList + `/${Number(item.organizationId)}`,
            }).then((res: any) => {
                userPageData.value.personList = res.data.data.map((item) => {
                    item.manager = item.manager ? '是' : '否'
                    return item
                })
                userPageData.value.personModal = true
            })
        }
        return { handleLink }
    })()

    // 获取部门全部数据
    function getDepartList(id = 0) {
        treeData.lists.forEach((treeData) => {
            whoOpen.value = [...whoOpen.value, ...ifOpen(treeData, 'organizationId')]
        })
        Server.Axios({
            method: 'GET',
            url:
                apiList.organization +
                `?organizationName=${screenData.organizationName.value || ''}`,
        }).then((res: any) => {
            if (id) {
                whoOpen.value = Array.from(
                    new Set([
                        ...whoOpen.value,
                        ...findParentData(id, res.data.data, 'organizationId'),
                    ])
                )
            }
            res.data.data.forEach((treeData) => {
                assignmentOpen(whoOpen.value, treeData, 'organizationId')
            })
            treeData.lists = res.data.data
            modalData.organizationBelong.data = res.data.data
            whoOpen.value = []
        })
    }
    // 获取管理者数据
    function getUserData() {
        Server.Axios({
            method: 'GET',
            url: apiList.userList,
        }).then((res: any) => {
            modalData.admin.data = res.data.data.map((item) => {
                item.name = item.username
                item.value = Number(item.userId)
                return item
            })
            modalData.user.data = modalData.admin.data
        })
    }

    function handleSearch(e) {
        getDepartList()
    }

    const handleDep = (() => {
        // 排序
        const onTreeDataChange = (list) => {
            if (screenData.organizationName.value) {
                return
            }
            treeData.lists = list
            Server.Axios({
                method: 'POST',
                url: apiList.sort,
                config: {
                    data: { organizations: flatten(list) },
                },
            }).then(() => {
                getDepartList()
            })
        }

        // 树结构扁平化
        function flatten(arr) {
            const result: any = []
            function flatten_inside(arr) {
                for (let i = 0; i < arr.length; i++) {
                    const item = arr[i]
                    result.push(item)
                    if (item.children && item.children.length > 0) {
                        flatten_inside(item.children)
                    }
                }
            }
            flatten_inside(arr)
            return result
        }

        //拖拽时的钩子
        function TreeDataChangeOver(e) {
            if (screenData.organizationName.value) {
                message.warning('搜索时不允许拖动')
                return false
            }
            return true
        }
        return { onTreeDataChange, TreeDataChangeOver }
    })()

    const addOrgFn = (() => {
        //增加弹窗前触发的钩子
        const modalAddOpen = () => {
            openModal('add', '添加部门')
            modalData.user.value = []
        }
        function modalAddClickOk() {
            Server.Axios({
                method: 'POST',
                url: apiList.organization,
                config: {
                    data: {
                        organizationName: modalData.organizationName.value,
                        parentId: modalData.organizationBelong.value || '0',
                        userId: modalData.admin.value,
                        orgUserIds: modalData.user.value,
                    },
                },
            }).then((res: any) => {
                message.success('添加成功')
                getDepartList(res.data.data.organizationId)
                cancelModal()
            })
        }

        return { modalAddOpen, modalAddClickOk }
    })()

    return {
        modalData, //列表数据
        treeData, //列表搜索条件
        userPageData, //弹窗数据
        columns, //列表数据
        screenData, //筛选模糊查询数据
        personColumns,
        paginationData,
        modalState,
        cancelModal, //取消弹窗时
        openModal,
        handleSearch,
        getDepartList,
        getUserData,
        addOrgFn,
        editOrgFn,
        deleteOrgFn,
        personDetail,
        handleDep,
    }
}
export { hooks }
