import { apiList, Server, handleModel, paginationFn, formatTime } from 'eyas-bashou-admin'
import { message } from 'ant-design-vue'
import qs from 'qs'

function hooks(initData) {
    const {
        modalData, //列表数据
        tableData, //列表搜索条件
        columns, //列表数据
        screenData, //筛选模糊查询数据
        paginationData, //分页数据
    } = initData
    const { pageChange, onShowSizeChange, updateTotal } = paginationFn(getRoleList, paginationData)
    const { modalState, cancelModal, openModal } = handleModel(modalData)

    // FN
    function getRoleList() {
        let fromData = qs.stringify({
            pageNo: paginationData.pageNo,
            pageSize: paginationData.pageSize,
            roleName: screenData.roleName.value,
            valid: screenData.valid.value,
        })

        Server.Axios({
            method: 'POST',
            url: apiList.getRole,
            config: {
                headers: {
                    'Content-Type': 'application/x-www-form-urlencoded',
                },
                data: fromData,
            },
        }).then((res: any) => {
            const result = res.data.data.list
            result.forEach((item, index) => {
                item.validName = item.valid == '0' ? '已禁用' : '已启用'
                item.idx = index + 1
                item.createTime = formatTime(item.createTime)
            })
            tableData.value = result
            updateTotal(res.data.data.total)
        })
    }
    // 获取菜单全部数据
    function deptTreeReq() {
        Server.Axios({
            method: 'GET',
            url: apiList.buttonTree,
        }).then((res: any) => {
            modalData.power.data = res.data.data
        })
    }

    function handleSearch() {
        paginationData.pageNo = 1
        getRoleList()
    }

    const addRoleFn = (() => {
        //增加弹窗前触发的钩子
        const modalAddOpen = (modalState) => {
            openModal(modalState.key, modalState.title)
        }

        /**
         * 新建用户
         * @param {type} roleName
         * @param {type} menuIds
         */
        function modalAddClickOk() {
            Server.Axios({
                method: 'POST',
                url: apiList.role,
                config: {
                    data: {
                        roleName: modalData.roleName.value,
                        menuIds: modalData.power.value,
                    },
                },
            }).then((res: any) => {
                message.success(res.data.returnInfo)
                cancelModal()
                modalReset()
                getRoleList()
            })
        }

        return { modalAddClickOk, modalAddOpen }
    })()

    const editRoleFn = (() => {
        /**
         * 获取回显数据
         * @param {type} roleId
         */
        function modalEditOpen(mData) {
            Server.Axios({
                method: 'GET',
                url: `/b/core/role/${mData.roleId}`,
            }).then((res: any) => {
                const { roleId, roleName, menuIds } = res.data.data
                modalData.roleName.value = roleName
                modalData.roleName.roleId = roleId
                modalData.power.value = menuIds
                openModal('update', '编辑用户')
            })
        }

        /**
         * 修改
         * @param {type} roleId roleName menuIds
         */
        function modalEditClickOk() {
            Server.Axios({
                method: 'PUT',
                url: apiList.role,
                config: {
                    data: {
                        roleId: modalData.roleName.roleId,
                        roleName: modalData.roleName.value,
                        menuIds: modalData.power.value,
                    },
                },
            }).then((res: any) => {
                message.success(res.data.returnInfo)
                cancelModal()
                getRoleList()
            })
        }

        return { modalEditClickOk, modalEditOpen }
    })()

    function forbiddenRoles(data) {
        Server.Axios({
            method: 'PUT',
            url: apiList.roleForbidden + `/${data.roleId}`,
        }).then(() => {
            getRoleList()
        })
    }

    //弹窗取消时
    function toCancelModal() {
        cancelModal()
        modalReset()
    }

    //重置弹窗方法
    function modalReset() {
        for (const item in modalData) {
            modalData[item].info = null
            modalData[item].value = null
            if (modalData[item].id) modalData[item].id = ''
        }
    }

    return {
        modalData, //列表数据
        tableData, //列表搜索条件
        columns, //列表数据
        screenData, //筛选模糊查询数据
        paginationData,
        modalState, //弹窗的状态
        cancelModal,
        getRoleList,
        deptTreeReq,
        handleSearch,
        ...addRoleFn,
        ...editRoleFn,
        forbiddenRoles,
        pageChange,
        onShowSizeChange,
        toCancelModal,
    }
}

export { hooks }
