import { apiList, Server, handleModel, paginationFn } from 'eyas-bashou-admin'
import md5 from 'js-md5'
import { message } from 'ant-design-vue'
function hooks(initData) {
    const {
        modalData, //列表数据
        tableData, //列表搜索条件
        columns, //列表数据
        screenData, //筛选模糊查询数据
        paginationData,
    } = initData
    //分页操作
    const { pageChange, onShowSizeChange, updateTotal } = paginationFn(getUserList, paginationData)

    //弹窗的打开和启用以及弹窗的状态
    const { modalState, cancelModal, openModal } = handleModel(modalData)

    /*
     *获取列表数据
     */
    function getUserList() {
        const data: any = {
            method: 'POST',
            url: apiList.userPage,
            config: {
                data: {
                    pageSize: paginationData.pageSize,
                    pageNo: paginationData.pageNo || 1,
                    username: screenData.username.value || '',
                    organizationName: screenData.organizationName.value || '',
                    valid: screenData.valid.value,
                },
            },
        }

        Server.From(data, columns.value).then((res: any) => {
            //添加索引字段以及把创建时间改为北京时间
            res.data.data.list.forEach((element, index) => {
                element.index = (paginationData.pageNo - 1) * paginationData.pageSize + index + 1
                element.validName = element.valid === '0' ? '禁用' : '启用'
            })
            //填充列表数据和总条数
            tableData.value = res.data.data.list
            updateTotal(res.data.data.total)
        })
    }

    //获取弹窗树状结构的部门管理数据
    const getOrganizationList = () => {
        const data: any = {
            method: 'GET',
            url: apiList.organization,
        }

        Server.Axios(data).then((res: any) => {
            modalData.department.data = res.data.data
        })
    }

    //获取弹窗下拉结构的角色管理数据
    const getRole = () => {
        const data: any = {
            method: 'GET',
            url: apiList.roleList,
        }

        Server.Axios(data).then((res: any) => {
            modalData.role.data = res.data.data
        })
    }

    //添加用户
    const addUserFn = (() => {
        //增加弹窗前触发的钩子
        const modalAddOpen = (modalState) => {
            getOrganizationList()
            getRole()
            modalData.username.id = ''
            modalData.password.info = ''
            modalData.password.isRequire = true
            openModal(modalState.key, modalState.title)
            modalData.role.value = []
        }

        //添加用户
        const addUser = () => {
            Server.Axios({
                method: 'POST',
                url: apiList.user,
                config: {
                    data: {
                        username: modalData.username.value,
                        nickname: modalData.nickname.value,
                        password: md5(modalData.password.value),
                        organizationId: modalData.department.value,
                        roleIds: modalData.role.value.join('-'),
                        valid: modalData.valid.value,
                    },
                },
            }).then((res: any) => {
                message.success('添加用户成功', 4)
                getUserList()
                cancelModal()
            })
        }

        return {
            modalAddOpen, //增加弹窗前触发的钩子
            addUser, //添加用户
        }
    })()

    //删除用户
    function deleteUserFn(e) {
        Server.Axios({
            method: 'DELETE',
            url: apiList.user + '/' + e.userId,
        }).then((res: any) => {
            message.success('操作成功', 4)
            getUserList()
        })
    }

    //修改用户
    const editUserFn = (() => {
        //修改弹窗前触发的钩子
        const modalEditOpen = async (mData) => {
            getOrganizationList()
            getRole()
            const _data: any = await Server.Axios({
                method: 'GET',
                url: apiList.user + '/' + mData.userId,
            })
            const _thisData = _data.data.data
            modalData.password.isRequire = false
            modalData.username.value = _thisData.username
            modalData.username.id = _thisData.userId
            modalData.nickname.value = _thisData.nickname
            modalData.department.value = _thisData.organizationId
            modalData.role.value = _thisData.roleIds
            modalData.valid.value = mData.valid
            openModal('update', '编辑用户')
        }
        //编辑用户
        const editUser = () => {
            Server.Axios({
                method: 'PUT',
                url: apiList.user,
                config: {
                    data: {
                        userId: modalData.username.id,
                        nickname: modalData.nickname.value,
                        password: modalData.password.value ? md5(modalData.password.value) : '',
                        organizationId: modalData.department.value,
                        roleIds: modalData.role.value.join('-'),
                        valid: modalData.valid.value,
                    },
                },
            }).then((res: any) => {
                message.success('修改用户成功', 4)
                cancelModal()
                getUserList()
            })
        }
        return {
            modalEditOpen, //修改弹窗前触发的钩子
            editUser, //编辑用户
        }
    })()

    //查询用户
    const clickSearch = () => {
        paginationData.pageNo = 1
        getUserList()
    }

    //禁用用户
    function disableUser(e) {
        Server.Axios({
            method: 'PUT',
            url: apiList.userForbidden,
            config: {
                data: {
                    userId: e.userId,
                    valid: e.valid == 1 ? 0 : 1,
                },
            },
        }).then((res: any) => {
            message.success('操作成功', 4)
            getUserList()
        })
    }

    function tableSorterFn() {
        getUserList()
    }

    return {
        paginationData, //分页数据
        modalData, //列表数据
        tableData, //列表搜索条件
        columns, //列表数据
        screenData, //筛选模糊查询数据
        modalState, //弹窗的状态
        getUserList, //获取列表数据
        cancelModal, //关闭弹窗
        addUserFn, //增加用户
        editUserFn, //修改用户
        deleteUserFn, //删除用户
        clickSearch, //查询用户
        disableUser, //禁用用户
        pageChange, //点击页码
        onShowSizeChange, //改变每页几条
        tableSorterFn,
    }
}

export { hooks }
